<?php

namespace App\domain\amadeus;

use App\Traits\FileStorageTrait;
use Exception;
use Illuminate\Support\Facades\Log;

class QueryDocIssuanceIssueTicketAction extends AmadeusRequestInSeries
{
    use FileStorageTrait;

    protected int $sequenceNumber;
    protected string $amadeusSessionId;
    protected string $amadeusSecurityToken;

    public function __construct()
    {
        parent::__construct();

        $this->sequenceNumber = 2;
    }

    public function execute(string $amadeusSessionId, string $amadeusSecurityToken): array
    {
        try {
            $this->amadeusSessionId = $amadeusSessionId;
            $this->amadeusSecurityToken = $amadeusSecurityToken;

            $response = $this->createCurlRequest();

            self::storeInFile("xml", "3.2-doc_issuance_issue_ticket_response", $response);

            $responseArray = $this->xmlResponseBodyToArray($response);

            self::storeInFile(
                "json", "3.2-doc_issuance_issue_ticket-response", json_encode($responseArray)
            );

            return $responseArray;

        } catch (Exception $exception) {
            $e = "Error in create TST From Pricing execute:" . $exception->getMessage();
            Log::error($e);
            echo $e;

            return ['error' => $e];
        }
    }

    protected function generateXMLRequest(): string
    {
        $xmlRequest = $this->xmlHeader($this->sequenceNumber, $this->amadeusSessionId, $this->amadeusSecurityToken) .
            "
            <soap:Body>
<DocIssuance_IssueTicket>
  <optionGroup>
    <switches>
      <statusDetails>
        <indicator>ET</indicator>
      </statusDetails>
    </switches>
  </optionGroup>
</DocIssuance_IssueTicket>
            </soap:Body>
        </soap:Envelope>
        ";

        self::storeInFile("xml", "3.2-doc_issuance_issue_ticket-request", $xmlRequest);

        return $xmlRequest;
    }

    protected function action(): string
    {
        return "http://webservices.amadeus.com/TTKTIQ_15_1_1A";
    }

}
